@@ -27,8 +27,8 @@ VALID_TRANSACTION_ACCOUNT_TYPES = [
     '!type:cash',
     '!type:bank',
     '!type:ccard',
-    '!type:oth a',
-    '!type:oth l',
+    '!type:otha',
+    '!type:othl',
     '!type:invoice'
 ]
 
@@ -246,7 +246,7 @@ class Qif(BaseModel):
                 )
                 accounts[last_account].add_transaction(
                     new_transaction,
-                    AccountType(header_line.replace(' ', '').split(':')[1]),
+                    AccountType(header_line.split(':')[1]),
                 )
 
                 if new_transaction.category:
@@ -511,7 +511,6 @@ class Qif(BaseModel):
     def to_dataframe(
         self,
         data_type: QifDataType = QifDataType.TRANSACTIONS,
-        # date_format: str = '%Y-%m-%d',
         ignore: List[str] = None,
     ) -> pd.DataFrame:
         """Convert part of the Qif object to a Pandas DataFrame. The
@@ -524,9 +523,6 @@ class Qif(BaseModel):
         data_type : QifDataType, optional
             The type of data to convert to a DataFrame, by default
             QifDataType.TRANSACTIONS
-        date_format : str, optional
-            The date format to use when converting dates to strings, by
-            default '%Y-%m-%d'
         ignore : List[str], optional
             A list of fields to ignore when converting to a DataFrame, by
             default None
